@@ -2,7 +2,7 @@ use std::path::{Path, PathBuf};
 
 use url::Url;
 
-use uv_cache_key::{cache_digest, CanonicalUrl};
+use uv_cache_key::{CanonicalUrl, cache_digest};
 use uv_distribution_types::IndexUrl;
 
 /// Cache wheels and their metadata, both from remote wheels and built from source distributions.
